#
# spec file for package gcr3
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name gcr
Name:           gcr3
Version:        3.41.2
Release:        1.4
# FIXME: Verify if the requires in typelib-1_0-Gcr-3 is still correct and required (see bgo#725501).
Summary:        Library for Crypto UI related tasks
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            http://www.gnome.org
Source0:        %{_name}-%{version}.tar.zst
Source1:        baselibs.conf
# PATCH-FIX-SLE gcr-bsc932232-use-libgcrypt-allocators.patch bsc#932232 hpj@suse.com -- use libgcrypt allocators for FIPS mode
Patch1:         gcr-bsc932232-use-libgcrypt-allocators.patch

# For directory ownership
BuildRequires:  dbus-1
BuildRequires:  gettext >= 0.19.8
BuildRequires:  gobject-introspection-devel >= 1.34
BuildRequires:  libgcrypt-devel >= 1.4.5
BuildRequires:  meson >= 0.52
BuildRequires:  pkgconfig(gi-docgen)
# configure is looking for the gpg2 path
BuildRequires:  openssh-clients
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.18.0.22
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gmodule-no-export-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(p11-kit-1) >= 0.19.0
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(systemd)

%description
GCR is a library for displaying certificates, and crypto UI, accessing
key stores. It also provides the viewer for crypto files on the GNOME
desktop.

GCK is a library for accessing PKCS#11 modules like smart cards, in a
(G)object oriented way.

%package viewer
Summary:        Viewer for Crypto Files
Group:          Productivity/Security
Provides:       %{_name}-viewer = %{version}
Conflicts:      %{_name}-viewer

%description viewer
This packages provides the viewer for crypto files on the GNOME desktop.

%package data
Summary:        Data and icon set for gcr
Group:          System/Libraries
Provides:       %{_name}-data = %{version}
Obsoletes:      %{_name}-data <= %{version}
Conflicts:      %{_name}-data

%description data
This package provides the GSettings schemas and a collection of icons
needed by libgcr.

%package prompter
Summary:        Prompt dialog for gcr
Group:          System/Libraries
Provides:       %{_name}-prompter = %{version}
Obsoletes:      %{_name}-prompter <= %{version}
Conflicts:      %{_name}-prompter

%description prompter
This package provides the prompt dialog needed by libgcr.

%package ssh-askpass
Summary:        SSH password callback helper for gcr
Group:          System/Libraries
Obsoletes:      %{_name}-ssh-askpass <= %{version}
Supplements:    (gpg2 and gnome-shell)

%description ssh-askpass
gcr-ssh-askpass allows an ssh command to callback for a password.

%package ssh-agent
Summary:        SSH agent binary for gcr
Group:          System/Libraries
Provides:       %{_name}-ssh-agent = %{version}
Obsoletes:      %{_name}-ssh-agent <= %{version}
Conflicts:      %{_name}-ssh-agent
Supplements:    (gpg2 and gnome-shell)

%description ssh-agent
gcr-ssh-agent as a standalone binary, so that it can easily be
managed through systemd.

%package -n libgcr-3-1
Summary:        Library for Crypto UI related tasks
Group:          System/Libraries
Requires:       %{_name}-data >= %{version}
Requires:       %{_name}-prompter >= %{version}
Recommends:     %{_name}-ssh-agent
Recommends:     %{name}-ssh-askpass
# https://bugzilla.opensuse.org/show_bug.cgi?id=1204071 - to properly manage keys using gnome-keyring
Requires:       (%{name}-ssh-askpass if gnome-keyring)
Recommends:     %{_name}-viewer
# To make lang package installable
Provides:       %{name} = %{version}

%description -n libgcr-3-1
GCR is a library for displaying certificates, and crypto UI, accessing
key stores.

%package -n typelib-1_0-Gcr-3
Summary:        Introspection bindings for gcr, a library for crypto UI related tasks
# Due to broken typelib files, this one cannot be automatically inspected
Group:          System/Libraries
Requires:       typelib-1_0-Gck-1

%description -n typelib-1_0-Gcr-3
GCR is a library for displaying certificates, and crypto UI, accessing
key stores.

This package provides the GObject Introspection bindings for GCR.

%package -n typelib-1_0-GcrUi-3
Summary:        Introspection bindings for gcr, a library for crypto UI related tasks
Group:          System/Libraries

%description -n typelib-1_0-GcrUi-3
GCR is a library for displaying certificates, and crypto UI, accessing
key stores.

This package provides the GObject Introspection bindings for GCR.

%package -n libgcr3-devel
Summary:        Development files for gcr, a library for crypto UI related tasks
Group:          Development/Libraries/GNOME
Requires:       libgcr-3-1 = %{version}
Requires:       typelib-1_0-Gcr-3 = %{version}
Requires:       typelib-1_0-GcrUi-3 = %{version}

%description -n libgcr3-devel
GCR is a library for displaying certificates, and crypto UI, accessing
key stores.

%package -n libgck-1-0
Summary:        GObject library to access PKCS#11 modules
# Small hack, to help gnome-keyring subpackage containing gck
# modules have a proper dependency, without having to care about
# the soname.
Group:          System/Libraries
Provides:       gck = %{version}

%description -n libgck-1-0
GCK is a library for accessing PKCS#11 modules like smart cards, in a
(G)object oriented way.

%package -n typelib-1_0-Gck-1
Summary:        Introspection bindings for gck, a GObject library to access PKCS#11 modules
Group:          System/Libraries

%description -n typelib-1_0-Gck-1
GCK is a library for accessing PKCS#11 modules like smart cards, in a
(G)object oriented way.

This package provides the GObject Introspection bindings for GCK.

%package -n libgck1-devel
Summary:        Development files for gck, a GObject library to access PKCS#11 modules
Group:          Development/Libraries/GNOME
Requires:       libgck-1-0 = %{version}
Requires:       typelib-1_0-Gck-1 = %{version}

%description -n libgck1-devel
GCK is a library for accessing PKCS#11 modules like smart cards, in a
(G)object oriented way.

%lang_package

%prep
%setup -q -n %{_name}-%{version}
%if 0%{?sle_version}
%patch -P 1 -p1
%endif

%build
%meson \
  -Dgpg_path=%{_bindir}/gpg2
%meson_build

%install
%meson_install
%suse_update_desktop_file gcr-prompter
%suse_update_desktop_file gcr-viewer
%find_lang %{_name}

%post -n libgcr-3-1 -p /sbin/ldconfig
%postun -n libgcr-3-1 -p /sbin/ldconfig
%post -n libgck-1-0 -p /sbin/ldconfig
%postun -n libgck-1-0 -p /sbin/ldconfig

%post -n %{name}-ssh-agent
%systemd_user_post gcr-ssh-agent.service

%preun -n %{name}-ssh-agent
%systemd_user_preun gcr-ssh-agent.service

%postun -n %{name}-ssh-agent
%systemd_user_postun_with_restart gcr-ssh-agent.service

%files viewer
%license COPYING
%doc NEWS
%{_bindir}/gcr-viewer
%{_datadir}/applications/gcr-viewer.desktop
%{_datadir}/mime/packages/gcr-crypto-types.xml

%files data
%doc NEWS
%{_datadir}/icons/hicolor/*/apps/*
# Own the directory since we can't depend on gconf providing them
%dir %{_datadir}/GConf
%dir %{_datadir}/GConf/gsettings
%{_datadir}/GConf/gsettings/org.gnome.crypto.pgp.convert
%{_datadir}/GConf/gsettings/org.gnome.crypto.pgp_keyservers.convert
%{_datadir}/glib-2.0/schemas/org.gnome.crypto.pgp.gschema.xml

%files prompter
%{_libexecdir}/gcr-prompter
%{_datadir}/applications/gcr-prompter.desktop
%{_datadir}/dbus-1/services/org.gnome.keyring.PrivatePrompter.service
%{_datadir}/dbus-1/services/org.gnome.keyring.SystemPrompter.service

%files ssh-askpass
%{_libexecdir}/gcr-ssh-askpass

%files ssh-agent
%{_libexecdir}/gcr-ssh-agent
%{_userunitdir}/gcr-ssh-agent.service
%{_userunitdir}/gcr-ssh-agent.socket

%files -n libgcr-3-1
%license COPYING
%doc NEWS
%{_libdir}/libgcr-base-3.so.*
%{_libdir}/libgcr-ui-3.so.*

%files -n typelib-1_0-Gcr-3
%{_libdir}/girepository-1.0/Gcr-3.typelib

%files -n typelib-1_0-GcrUi-3
%{_libdir}/girepository-1.0/GcrUi-3.typelib

%files -n libgcr3-devel
%doc %{_datadir}/doc/gcr*/
%{_libdir}/libgcr-base-3.so
%{_libdir}/libgcr-ui-3.so
%{_libdir}/pkgconfig/gcr-3.pc
%{_libdir}/pkgconfig/gcr-base-3.pc
%{_libdir}/pkgconfig/gcr-ui-3.pc
%dir %{_includedir}/gcr-3
%{_includedir}/gcr-3
%{_datadir}/gir-1.0/GcrUi-3.gir

%files -n libgck-1-0
%license COPYING
%doc NEWS
%{_libdir}/libgck-1.so.*

%files -n typelib-1_0-Gck-1
%{_libdir}/girepository-1.0/Gck-1.typelib

%files -n libgck1-devel
%doc %{_datadir}/doc/gck*/
%{_libdir}/libgck-1.so
%{_libdir}/pkgconfig/gck-1.pc
%{_includedir}/gck-1/
%{_datadir}/gir-1.0/Gck-1.gir
%{_datadir}/gir-1.0/Gcr-3.gir
%{_datadir}/vala/vapi/

%files lang -f %{_name}.lang

%changelog
* Thu Jan 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.41.2:
  + ui: Add gcr.gresource.xml back into the build.
  + misc: Several memory leaks were fixed.
  + ci: Several CI fixes.
  + Updated translations.
- Changes from version 3.41.1:
  + meson: Fix unknown kw argument in gnome.generate_gir.
  + gcr: Add G_SPAWN_CLOEXEC_PIPES flag to all the g_spawn
    commands.
  + docs: Port from gtk-doc to gi-docgen.
  + Unbreak build without systemd.
  + Several CI fixes.
  + Updated translations.
- Drop b3ca1d02bb0148ca787ac4aead164d7c8ce2c4d8.patch: fixed
  upstream.
- Replace gtk-doc buildRequires with pkgconfig(gi-docgen): follow
  upstreams port of the documentation infrastructure.
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -p N instead of deprecated %%patchN.
* Tue Oct 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Have libgcr-3-1 require gcr3-ssh-askpass when gnome-keyring is
  present: gnome-keyring interacts deeper with this library, which
  justifies a hard dep in this case (boo#1204071).
* Fri Sep 16 2022 Dominique Leuenberger <dimstar@opensuse.org>
- gcr-ssh-askpass: this package does still exist on gcr4 too, but
  the two are not interchanchable. The binary though has a
  different name, so they do not conflict. Drop the
  provides/obsoletes on gcr-ssh-askpass and recommend
  gcr-ssh-askpass by the library.
* Thu Sep 15 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add provides/conflicts to the sub packages to co-exist with gcr:
  + gcr3-data provides gcr-data and conflicts with gcr-data:
    packages provided by gcr and gcr3 will thus be picked from gcr
    (higher version)
  + Same setup done for gcr3-viewew, -prompter, -ssh-askpass, and
  - ssh-agent.
* Fri Aug  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Rename package to gcr3, as compat stack.
* Tue Feb  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add b3ca1d02bb0148ca787ac4aead164d7c8ce2c4d8.patch: Fix build
  with meson 060.0 and newer.
* Tue Oct  5 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.41.0:
  +  Port ssh-agent from gnome-keyring.
  + build: Fix parallel build failure due to missing marshal
    dependency.
  + Fix warnings by dropping `volatile` for g_once_init_inter
    locations.
  + tests: More robust against GTask unref race condition.
  + Updated translations.
- Add pkgconfig(libsecret-1), pkgconfig(libsystemd),
  pkgconfig(systemd) and openssh-clients BuildRequires: Build new
  standalone ssh-agent, and split it out in own sub-package.
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.40.0:
  + FEATURE: add hkps://keys.openpgp.org to keyserver defaults.
  + gcr/key-mechanism: Port to GTask.
  + GckCall: Simplify the code by using GTask based implementation.
  + Updated translations.
- Make use of the new gpg_path meson option by passing
  %%{_bindir}/gpg2 as value to it: We know that openSUSE installs
  gpg2 to this path. Allows to drop gpg2 BuildRequires.
- Drop pkgconfig(gtk+-x11-3.0) BuildRequires: no longer needed.
* Wed Jan 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.1:
  + ui: Set "use-underline" for GcrImportButton.
  + Updated translations.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + No changes from 3.37.91.
- Changes from version 3.37.91:
  + meson: missing dependency on generated oids header.
  + Correct display of key usage extensions.
  + meson: Correctly set internal vapi dependencies.
  + Cleanup GType boilerplate.
  + gck: Fixed test failures.
  + Updated translations.
* Wed Apr 29 2020 Michael Gorse <mgorse@suse.com>
- Enable FIPS patch on Leap (jsc#SLE-11855).
* Wed Mar 11 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + gcr: Update gtk-doc get_der_data() vfunc.
  + Updated translations.
* Tue Feb 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Mark deprecated functions with G_DEPRECATED.
  + egg-oid: Add comments for translators for new abbrevations.
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Add support for "NEW CERTIFICATE REQUEST" header.
  + Add support for GOST certificates.
  + Rework handling of ASN.1 standard types.
  + Fix a few regressions in the Meson build.
  + Add support for g_autoptr.
  + Fixed some compiler warnings.
- Changes from version 3.35.1:
  + gcr-certificate: Add (virtual) annotation.
  + Always use G_PARAM_STATIC_STRINGS.
  + Support Meson build system.
  + Avoid potential 64-bit pointer aliasing alignment issues.
  + Update README to mention correct environment variables.
  + build: Use sed for .desktop variables substitution.
  + Updated translations.
- Switch to meson buildsystem: replace configure/make/make_install
  macros with the meson/meson_build/meson_install counterparts.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Nov 28 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Fix usage of libexecdir instead of prefix/lib where applicable.
* Mon Oct 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + gcr-prompt-dialog: Allow the use of mnemonics in the choice
    label (glgo#GNOME/gcr!22).
  + Use python3 shebang in ui/icons/render-icons.py
    (glgo#GNOME/gcr!21).
  + configure: Use PKG_PROG_PKG_CONFIG instead of reinventing it
    (glgo#GNOME/gcr!20).
  + Replace tap-gtester with one that relies on GLib 2.38+ TAP
    output (glgo#GNOME/gcr!19).
  + Remove SKS network from keyserver defaults (glgo#GNOME/gcr!18).
  + Updated translations.
* Sun Sep  1 2019 mgorse@suse.com
- Update to version 3.33.4:
  + Move from intltool to gettext.
  + Fix parameter type for signal handler causing stack smashing on
    ppc64le.
  + cleanup: Don't use deprecated g_type_class_add_private()
    anymore.
  + Fix GIR annotations.
  + Fix hashtable ordering assumptions.
  + build: Fix gcr-trust symbols not appearing in GIR, and hence
    also VAPI.
  + Update gcr_pkcs11_get_trust_{store|lookup}_slot URI checks.
  + build: Update tap scripts for Python 3 compat.
  + Updated translations.
- Drop intltool dependency, and add gettext.
* Fri Jan 18 2019 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + system-prompter: Fix use of g_hash_table_lookup_extended.
  + Updated translations.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Fix year 2038 workaround in ASN.1 decoder (bgo#787963).
  + Fix test errors when ssh-keygen is not found.
  + Updated translations.
* Sun Mar 11 2018 dimstar@opensuse.org
- Supplement the new gcr-ssh-askpass for gpg2 and gnome-shell:
  GNOME users want to have this available to enter the ssh key
  passwords.
* Fri Mar  9 2018 jengelh@inai.de
- Fix SRPM group. Update package summaries.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Provide API for reliably calling ssh programs (bgo#735873).
  + Updated translations.
- Split new subpackage gcr-ssh-askpass, recommended by the main
  library.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb 27 2018 luc14n0@linuxmail.org
- Update to version 3.27.4:
  + Fixes:
  - Encoding of EC parameters (bgo#785234).
  - Hang in certificate export dialog (bgo#789804).
  - Failure case in gcr_secure_memory_try_realloc() (bgo#775685).
  + Switch to using GLib resources.
  + Build fixes: bgo#771052, bgo#775685, bgo#775966, bgo#774312,
    bgo#774311, bgo#764562, bgo#764569.
  + Updated translations.
- Drop %%desktop_database_*, %%mime_database_*, %%icon_theme_cache_*
  and %%glib2_gsettings_schema_* post/postun scriptlets and
  %%glib2_gsettings_schema_requires macro: they're no longer needed
  since RPM File Triggers cover their functionality now.
- Drop shared-mime-info BuildRequires: it's no longer needed now
  that its macros are not used anymore.
- Drop pkgconfig(libtasn1) BuildRequires: it's no longer needed nor
  used anymore.
- Adopt the use of %%make_build macro rather than raw make command,
  following the best practices.
- Add gtk-doc BuildRequires and pass enable-gtk-doc to configure as
  the API's documentation is desired.
- Add pkgconfig(gtk+-x11-3.0) BuildRequires: it was being pulled
  by gtk+-3.0 pkgconfig module and used already, since both of them
  lives in gtk3-devel package.
- Rebase gcr-bsc932232-use-libgcrypt-allocators.patch.
* Tue Feb 27 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
* Mon Feb 26 2018 crrodriguez@opensuse.org
- Add explicit pkgconfig(pango) and pkgconfig(cairo) BuildRequires:
  closer alignment with what configure checks for.
* Wed Aug 31 2016 fezhang@suse.com
- Add openSUSE conditional macro and description tag for existing
  patches in specfile.
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 -- Fate#318572.
* Fri Mar 25 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Build fixes (bgo#763488, bgo#766301).
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Build fixes (bgo#756235, bgo#755873).
  + Updated translations.
* Thu Nov 26 2015 hpj@suse.com
- Add gcr-bsc932232-use-libgcrypt-allocators.patch (bsc#932232).
* Tue Sep 29 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Tue Aug  4 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Bump up the GTK+ deps.
  + Build fixes.
  + Updated translations.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + No changes from 3.15.92.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Build fixes (bgo#745629).
  + Updated translations.
* Wed Feb 25 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Fix memory leaks (bgo#738508, bgo#739239).
  + Build fixes (bgo#743201, bgo#739449, #bgo737622).
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Tue Sep  9 2014 dimstar@opensuse.org
- Update to version 3.13.91:
  + Add support for parsing EC keys (bgo#672137).
  + Add support for EC keys to key renderer.
  + Parser support for PEM 'PUBLIC KEY' files.
  + Parser support for parsing ECDSA OpenSSH keys.
  + Fix use of libgcrypt 1.6+.
  + Fix for deprecations in Gtk 3.13.x.
  + Use g_debug() instead of our own debug wrappers.
  + Bump required GLib version to 2.38.x.
  + Don't include deprecated library in our pkg-config file
    (bgo#732082).
  + Don't use non-portable 'sed -i' shell command (bgo#728506).
  + Change CVS to Git in error message (bgo#730340).
  + Build fixes.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Thu Apr  3 2014 dimstar@opensuse.org
- Require typelib-1_0-Gck-1 by typelib-1_0-Gcr-3: this is a work-
  around for upstreams broken files, which results in Gcr having
  internally the version '3.broken' instead of '3' (bgo#725501).
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Use /usr/bin/env to find python (bgo#726909).
  + Updated translations.
* Fri Mar  7 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Parallel tests, non-recursive Makefile, and TAP.
  + Add gck_enumerator_set_object_type_full() function.
  + Add an accessor for GckAttribute raw value data.
  + Add gcr_certificate_get_markup() function.
  + Store imported key filename in GcrParsed & GcrParser
    (bg#705225).
  + Allow using GBytes with GcrParser (bgo#708736).
  + Lots of VAPI and GIR fixes (bgo#720504 and others).
  + Deprecation fixes.
- Add xsltproc BuildRequires: new dependency.
* Thu Oct 17 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 zaitor@opensuse.org
- Update to version 3.10.0:
  + Fix annotations (bgo#705225).
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Bugs fixed: bgo#707077, bgo#707078.
  + Updated translations.
* Mon Aug 26 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + GcrCertificateWidget: inherit from GtkBin, not GtkWidget
    (bgo#701048).
  + Made gcr-certificate-renderer close the dialog when clicking
    okay (bgo#699543).
  + Port to new p11-kit managed style functions.
  + Testing fixes (bgo#705139).
  + Build fixes (bgo#695973).
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Vapi bindings (bgo#689685).
  + Don't import to 'xdg' module in the importer.
  + Add appropriate icon for p11-kit trust module.
  + Handle cases where no certificate data is available.
  + Build fixes.
- Add vala BuildRequires: new dependency for the vapi bindings.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Fix erroneously cancelled prompts.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Fix crash when hashing an unsupported attributes (bgo#696305).
  + Updated translations.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Have the gcr-prompter replace the running prompter.
  + Fix segfault when prompt is dismissed immediately.
  + Updated translations.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Bugs fixed: bgo#687980, bgo#692536, bgo#693440, bgo#693591.
  + Updated translations.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Separate the base and ui parts of the Gcr library more
    thoroughly.
  + Fix crasher in armor parsing code.
  + Build fixes.
  + Updated translations.
- Create new sub-package typelib-1_0-GcrUi-3, following upstreams
  split of the Ui part of the library.
* Wed Dec 26 2012 dimstar@opensuse.org
- Update to version 3.7.2:
  + Fix corner case in DER parsing.
  + Fix crash when parsing invalid DER.
  + More complete test coverage.
  + Other minor fixes.
  + Build fixes.
* Wed Dec 26 2012 dimstar@opensuse.org
- Update to version 3.7.1:
  + Allow system prompts to be cancelled while in 'checking' state.
  + Cancel system prompts when the prompter goes away.
  + Use gnome-common code coverage macros.
  + Build fixes.
  + Updated translations.
* Sun Dec  9 2012 dimstar@opensuse.org
- Add baselibs.conf in order to provide these -32bit packages:
  + libgck-1-0.
  + libgck-devel.
  + libgcr-3-1 (Needed by libgdata13-32bit).
  + libgcr-devel.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Updated translations.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Clear and focus password entry in gcr-viewer when invalid
    password.
  + Keep enumerating if getting info about one slot fails.
  + Testing fixes.
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Tue Sep 18 2012 zaitor@opensuse.org
- Enable parallel building again.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Don't fail preconditions when pkcs11 isn't initialized in gcr.
  + Fix regression in ASN.1 parsing.
  + Build fixes.
  + Updated translations.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Use p11-kit/pkcs11.h instead of shipping a copy with gck.
  + Documentation fixes.
  + Updated translations.
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Add debug output to GcrSecretExchange
  + Fix invalid warning when sending a secret exchange
  + Remove support code for old glib versions
  + Documentation fixes
  + Updated translations.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Rework DER parsing so we can parse odd PKCS#12 files.
  + Use GBytes, bump glib dependency.
  + Enable gnome2 keyring storage.
  + Documentation fixes.
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Fix more issues disabling grabs during password prompts
  + More debug messages to GcrSystemPrompter
  + Fix up GCR_DEBUG and GCK_DEBUG environment variables
  + Build fixes
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + No changes.
* Mon Mar 19 2012 zaitor@opensuse.org
- Update to version 3.3.92:
  + Fix up copyright headers.
  + Build fix.
  + Updated translations.
* Thu Mar  1 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Expose the secure memory API
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Fri Feb 10 2012 dimstar@opensuse.org
- Update to version 3.3.5:
  + Add way to specify button labels for a GcrPrompt.
  + Reenable grabs for password prompts.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Display an appropriate title in gcr-viewer
  + Include GcrPrompt documentation
  + Add 'new-prompt' signal to GcrSystemPrompter for use with
    javascript
  + Fix build for glib 2.31 deprecations
  + Build fixes
* Wed Dec 21 2011 vuntz@opensuse.org
- Update to version 3.3.3.1:
  + Fix build issues
* Mon Dec 19 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Add support for parsing PKCS#10 and SPKAC formats in GcrParser
  + Add support for viewing certificate requests in GcrViewer
  + Support for dynamically loading private key data from PKCS#11
  + Add GcrCertificateRequest class for requesting certificates
  + Add function to retrieve basic constraints from a certificate
  + Show import errors in an info bar under the viewer
  + Don't show empty dates in gnupg key renderer
  + Make secure memory pool shared across modules
  + Add GckBuilder as a mutable attribute set
  + Add floating references to GckAttributes
  + Rename GckObjectAttributes to GckObjectCache
  + Expose GcrSecureEntryBuffer as a public class
  + Add system prompt and prompter
  + Expose uri in GcrImporter
  + Fix build for glib 2.31 deprecations
  + Licensing fixes
  + Build fixes, internal bug fixes, documentation, etc.
- Add dbus-1 BuildRequires: needed for directory ownership.
- Add pkgconfig(gio-unix-2.0) BuildRequires: new dependency.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Create a gcr-prompter subpackage for the new gcr-prompter binary.
  As it is required by libgcr for some uses, add a Requires for it
  to libgcr-3-1.
- Add a gcr Provides to libgcr-3-1 to make the lang subpackage
  installable.
- Add a gck Provides to libgck-1-0, as a helper for gnome-keyring
  where we want an explicit Requires on this library package.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib files into their own subpackages: typelib-1_0-Gcr-3
  and typelib-1_0-Gck-1.
- Add typelib-1_0-Gcr-3 Requires to libgcr-devel and
  typelib-1_0-Gck-1 Requires to libgck-devel.
* Tue Nov 22 2011 dimstar@opensuse.org
- Update to version 3.3.2.1:
  + Fix build issues
- Drop gcr-glib-includes.patch: fixed upstream.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Allow changing collection on a GcrCollectionModel, add
    tree/list mode to GcrCollectionModel
  + Allow chaining of GckEnumerator objects, so that when objects
    from one is listed, then chained enumerator is enumerated.
  + Integrate GTlsInteraction into libgck for logging in or key
    auth.
  + Refactor internal DER parsing to use reference counted memory
    using the prototyped GBytes API.
  + Build fixes, documentation fixes, testing fixes, memory leak
    fixes.
- Add gcr-glib-includes.patch: Don't include internal glib headers.
- Re-add gobject-introspection-devel BuildRequires to re-enable
  introspection support.
- Add gpg2 BuildRequires as configure is looking for the binary.
* Thu Oct 27 2011 dimstar@opensuse.org
- Initial package, library has been split out of gnome-keyring.
